Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(526)

Unified Diff: remoting/signaling/xmpp_signal_strategy.cc

Issue 810133003: replace NULL->nullptr in src/remoting. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/signaling/server_log_entry_unittest.cc ('k') | remoting/test/fake_socket_factory.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/signaling/xmpp_signal_strategy.cc
diff --git a/remoting/signaling/xmpp_signal_strategy.cc b/remoting/signaling/xmpp_signal_strategy.cc
index 6ff287d85701efdd2a8f4ec3b61fe269ba5c27d3..c86292361277a3a222460947751421c50a2212ca 100644
--- a/remoting/signaling/xmpp_signal_strategy.cc
+++ b/remoting/signaling/xmpp_signal_strategy.cc
@@ -53,7 +53,7 @@ XmppSignalStrategy::XmppSignalStrategy(
: socket_factory_(socket_factory),
request_context_getter_(request_context_getter),
resource_name_(kDefaultResourceName),
- xmpp_client_(NULL),
+ xmpp_client_(nullptr),
xmpp_server_config_(xmpp_server_config),
state_(DISCONNECTED),
error_(OK) {
@@ -138,9 +138,9 @@ void XmppSignalStrategy::Disconnect() {
xmpp_client_->Disconnect();
// |xmpp_client_| should be set to NULL in OnConnectionStateChanged()
// in response to Disconnect() call above.
- DCHECK(xmpp_client_ == NULL);
+ DCHECK(xmpp_client_ == nullptr);
}
}
@@ -195,7 +195,7 @@ bool XmppSignalStrategy::HandleStanza(const buzz::XmlElement* stanza) {
DCHECK(CalledOnValidThread());
ObserverListBase<Listener>::Iterator it(listeners_);
Listener* listener;
- while ((listener = it.GetNext()) != NULL) {
+ while ((listener = it.GetNext()) != nullptr) {
if (listener->OnSignalStrategyIncomingStanza(stanza))
return true;
}
@@ -236,7 +236,7 @@ void XmppSignalStrategy::OnConnectionStateChanged(
// Client is destroyed by the TaskRunner after the client is
// closed. Reset the pointer so we don't try to use it later.
- xmpp_client_ = NULL;
+ xmpp_client_ = nullptr;
switch (error) {
case buzz::XmppEngine::ERROR_UNAUTHORIZED:
« no previous file with comments | « remoting/signaling/server_log_entry_unittest.cc ('k') | remoting/test/fake_socket_factory.cc » ('j') | no next file with comments »
@@ -138,9 +138,9 @@ void XmppSignalStrategy::Disconnect() {
xmpp_client_->Disconnect();
- // |xmpp_client_| should be set to NULL in OnConnectionStateChanged()
+ // |xmpp_client_| should be set to nullptr in OnConnectionStateChanged()
// in response to Disconnect() call above.

Powered by Google App Engine
This is Rietveld 408576698